/****************************************************************************
** Meta object code from reading C++ file 'sessionthread_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ksmtp-26.07.80/src/sessionthread_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionthread_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5KSmtp13SessionThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto KSmtp::SessionThread::qt_create_metaobjectdata<qt_meta_tag_ZN5KSmtp13SessionThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSmtp::SessionThread",
        "encryptionNegotiationResult",
        "",
        "encrypted",
        "QSsl::SslProtocol",
        "protocol",
        "responseReceived",
        "KSmtp::ServerResponse",
        "response",
        "sslError",
        "KSslErrorUiData",
        "reconnect",
        "closeSocket",
        "startSsl",
        "sendData",
        "payload",
        "sslConnected",
        "writeDataQueue",
        "readResponse",
        "doCloseSocket",
        "doHandleSslErrorResponse",
        "ignoreError"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'encryptionNegotiationResult'
        QtMocHelpers::SignalData<void(bool, QSsl::SslProtocol)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'responseReceived'
        QtMocHelpers::SignalData<void(const KSmtp::ServerResponse &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'sslError'
        QtMocHelpers::SignalData<void(const KSslErrorUiData &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'reconnect'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeSocket'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startSsl'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendData'
        QtMocHelpers::SlotData<void(const QByteArray &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 15 },
        }}),
        // Slot 'sslConnected'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'writeDataQueue'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'readResponse'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doCloseSocket'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doHandleSslErrorResponse'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SessionThread, qt_meta_tag_ZN5KSmtp13SessionThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSmtp::SessionThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KSmtp13SessionThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KSmtp13SessionThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5KSmtp13SessionThreadE_t>.metaTypes,
    nullptr
} };

void KSmtp::SessionThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SessionThread *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->encryptionNegotiationResult((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSsl::SslProtocol>>(_a[2]))); break;
        case 1: _t->responseReceived((*reinterpret_cast<std::add_pointer_t<KSmtp::ServerResponse>>(_a[1]))); break;
        case 2: _t->sslError((*reinterpret_cast<std::add_pointer_t<KSslErrorUiData>>(_a[1]))); break;
        case 3: _t->reconnect(); break;
        case 4: _t->closeSocket(); break;
        case 5: _t->startSsl(); break;
        case 6: _t->sendData((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 7: _t->sslConnected(); break;
        case 8: _t->writeDataQueue(); break;
        case 9: _t->readResponse(); break;
        case 10: _t->doCloseSocket(); break;
        case 11: _t->doHandleSslErrorResponse((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SessionThread::*)(bool , QSsl::SslProtocol )>(_a, &SessionThread::encryptionNegotiationResult, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionThread::*)(const KSmtp::ServerResponse & )>(_a, &SessionThread::responseReceived, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionThread::*)(const KSslErrorUiData & )>(_a, &SessionThread::sslError, 2))
            return;
    }
}

const QMetaObject *KSmtp::SessionThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSmtp::SessionThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KSmtp13SessionThreadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int KSmtp::SessionThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KSmtp::SessionThread::encryptionNegotiationResult(bool _t1, QSsl::SslProtocol _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KSmtp::SessionThread::responseReceived(const KSmtp::ServerResponse & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KSmtp::SessionThread::sslError(const KSslErrorUiData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
